@@ -1,4 +1,4 @@
-//! Provides generic datatypes used across multiple Tinychain sub-crates.
+//! Provides generic data types used across multiple Tinychain sub-crates.
 //!
 //! This library is a part of Tinychain: [http://github.com/haydnv/tinychain](http://github.com/haydnv/tinychain)
 
@@ -11,24 +11,25 @@ use tc_error::*;
 
 pub use id::*;
 pub use map::*;
-pub use stream::*;
 pub use time::*;
 pub use tuple::*;
 
-pub mod id;
-pub mod map;
-pub mod stream;
-pub mod time;
-pub mod tuple;
+mod id;
+mod map;
+mod time;
+mod tuple;
+
+/// A pinned future
+pub type TCBoxFuture<'a, T> = Pin<Box<dyn Future<Output = T> + Send + 'a>>;
 
 /// A pinned future which returns a [`TCResult`]
 pub type TCBoxTryFuture<'a, T> = Pin<Box<dyn Future<Output = TCResult<T>> + Send + 'a>>;
 
 /// A pinned [`Stream`]
-pub type TCStream<'a, T> = Pin<Box<dyn Stream<Item = T> + Send + Unpin + 'a>>;
+pub type TCBoxStream<'a, T> = Pin<Box<dyn Stream<Item = T> + Send + Unpin + 'a>>;
 
 /// A pinned `TryStream` with error type [`TCError`]
-pub type TCTryStream<'a, T> = Pin<Box<dyn Stream<Item = TCResult<T>> + Send + Unpin + 'a>>;
+pub type TCBoxTryStream<'a, T> = Pin<Box<dyn Stream<Item = TCResult<T>> + Send + Unpin + 'a>>;
 
 /// A generic class trait
 pub trait Class: fmt::Display + Sized {}
