@@ -9,6 +9,7 @@ use async_trait::async_trait;
 use destream::de::{Decoder, FromStream};
 use destream::en::{Encoder, IntoStream, ToStream};
 use safecast::{Match, TryCastFrom, TryCastInto};
+use serde::{Deserialize, Deserializer, Serialize, Serializer};
 
 use tc_error::*;
 
@@ -16,11 +17,11 @@ use super::{Id, Tuple};
 
 /// A generic map whose keys are [`Id`]s, based on [`BTreeMap`]
 #[derive(Clone)]
-pub struct Map<T: Clone> {
+pub struct Map<T> {
     inner: BTreeMap<Id, T>,
 }
 
-impl<T: Clone> Map<T> {
+impl<T> Map<T> {
     pub fn new() -> Self {
         Self {
             inner: BTreeMap::new(),
@@ -70,27 +71,27 @@ impl<T: Clone> Map<T> {
     }
 }
 
-impl<T: Clone> Default for Map<T> {
+impl<T> Default for Map<T> {
     fn default() -> Map<T> {
         BTreeMap::new().into()
     }
 }
 
-impl<T: Clone + PartialEq> PartialEq for Map<T> {
+impl<T: PartialEq> PartialEq for Map<T> {
     fn eq(&self, other: &Self) -> bool {
         self.inner == other.inner
     }
 }
 
-impl<T: Clone + PartialEq + Eq> Eq for Map<T> {}
+impl<T: PartialEq + Eq> Eq for Map<T> {}
 
-impl<T: Clone> AsRef<BTreeMap<Id, T>> for Map<T> {
+impl<T> AsRef<BTreeMap<Id, T>> for Map<T> {
     fn as_ref(&self) -> &BTreeMap<Id, T> {
         &self.inner
     }
 }
 
-impl<T: Clone> Deref for Map<T> {
+impl<T> Deref for Map<T> {
     type Target = BTreeMap<Id, T>;
 
     fn deref(&'_ self) -> &'_ Self::Target {
@@ -98,13 +99,13 @@ impl<T: Clone> Deref for Map<T> {
     }
 }
 
-impl<T: Clone> DerefMut for Map<T> {
+impl<T> DerefMut for Map<T> {
     fn deref_mut(&'_ mut self) -> &'_ mut <Self as Deref>::Target {
         &mut self.inner
     }
 }
 
-impl<T: Clone> IntoIterator for Map<T> {
+impl<T> IntoIterator for Map<T> {
     type Item = (Id, T);
     type IntoIter = <BTreeMap<Id, T> as IntoIterator>::IntoIter;
 
@@ -113,20 +114,20 @@ impl<T: Clone> IntoIterator for Map<T> {
     }
 }
 
-impl<T: Clone> FromIterator<(Id, T)> for Map<T> {
+impl<T> FromIterator<(Id, T)> for Map<T> {
     fn from_iter<I: IntoIterator<Item = (Id, T)>>(iter: I) -> Self {
         let inner = BTreeMap::from_iter(iter);
         Map { inner }
     }
 }
 
-impl<T: Clone> From<BTreeMap<Id, T>> for Map<T> {
+impl<T> From<BTreeMap<Id, T>> for Map<T> {
     fn from(inner: BTreeMap<Id, T>) -> Self {
         Map { inner }
     }
 }
 
-impl<F: Clone, T: Clone> TryCastFrom<Tuple<F>> for Map<T>
+impl<F, T> TryCastFrom<Tuple<F>> for Map<T>
 where
     (Id, T): TryCastFrom<F>,
 {
@@ -150,7 +151,7 @@ where
 }
 
 #[async_trait]
-impl<T: Clone + FromStream<Context = ()>> FromStream for Map<T>
+impl<T: FromStream<Context = ()>> FromStream for Map<T>
 where
     T::Context: Copy,
 {
@@ -162,19 +163,31 @@ where
     }
 }
 
-impl<'en, T: Clone + IntoStream<'en> + 'en> IntoStream<'en> for Map<T> {
+impl<'en, T: IntoStream<'en> + 'en> IntoStream<'en> for Map<T> {
     fn into_stream<E: Encoder<'en>>(self, encoder: E) -> Result<E::Ok, E::Error> {
         self.inner.into_stream(encoder)
     }
 }
 
-impl<'en, T: Clone + ToStream<'en> + 'en> ToStream<'en> for Map<T> {
+impl<'en, T: ToStream<'en> + 'en> ToStream<'en> for Map<T> {
     fn to_stream<E: Encoder<'en>>(&'en self, encoder: E) -> Result<E::Ok, E::Error> {
         self.inner.to_stream(encoder)
     }
 }
 
-impl<F: Clone, T: TryCastFrom<F>> TryCastFrom<Map<F>> for BTreeMap<Id, T> {
+impl<'de, T: Deserialize<'de>> Deserialize<'de> for Map<T> {
+    fn deserialize<D: Deserializer<'de>>(deserializer: D) -> Result<Self, D::Error> {
+        BTreeMap::deserialize(deserializer).map(|inner| Self { inner })
+    }
+}
+
+impl<T: Serialize> Serialize for Map<T> {
+    fn serialize<S: Serializer>(&self, serializer: S) -> Result<S::Ok, S::Error> {
+        self.inner.serialize(serializer)
+    }
+}
+
+impl<F, T: TryCastFrom<F>> TryCastFrom<Map<F>> for BTreeMap<Id, T> {
     fn can_cast_from(map: &Map<F>) -> bool {
         map.values().all(|f| T::can_cast_from(f))
     }
@@ -194,7 +207,7 @@ impl<F: Clone, T: TryCastFrom<F>> TryCastFrom<Map<F>> for BTreeMap<Id, T> {
     }
 }
 
-impl<T: Clone + fmt::Debug> fmt::Debug for Map<T> {
+impl<T: fmt::Debug> fmt::Debug for Map<T> {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         if self.is_empty() {
             return f.write_str("{}");
@@ -212,7 +225,7 @@ impl<T: Clone + fmt::Debug> fmt::Debug for Map<T> {
     }
 }
 
-impl<T: Clone + fmt::Display> fmt::Display for Map<T> {
+impl<T: fmt::Display> fmt::Display for Map<T> {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         if self.is_empty() {
             return f.write_str("{}");
